get_rank: Rank of a non-metric variable
Description
Internal function not to be called by the userArguments
X
an ordinal or nominal manifest variable to be
ranked
Value
- vector with the corresponding rank for each category
Warning
Do NOT use this function unless you are ME, a package
developer, or a jedi user who really knows what is doing
(seriously!)Details
Internal function. get_rank is called by
get_treated_data and get_weights.