get_rho: Calculate Dillon-Goldstein's rho
Description
Internal function not to be called by the userUsage
get_rho(Block, score)
Arguments
Block
matrix (one block) of standardized manifest
variables
score
first principal component of Block
Warning
Do NOT use this function unless you are ME, a package
developer, or a jedi user who really knows what is doing
(seriously!)Details
Internal function. get_rho is called by
get_unidim and rho.